-- 时空争霸
Lua_TimeSpaceRaceWindow = class("Lua_TimeSpaceRaceWindow", Lua_Window)
function Lua_TimeSpaceRaceWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_TimeSpaceRaceWindow";
	self.skinName = "TimeSpaceRaceWindow_skin";
	self.isFullSizeWin = true;
	self.isSingleShowWin = true;
	self.winSceneId = DataCenter.timeSpaceRaceData.sceneId;
end

function Lua_TimeSpaceRaceWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.bRace = false;
	self.spaceType = 1;
	self.coolTime = 0;
	self.modelLen = 0;

	self:addLuaEvent("TIME_SPACE_RACE_INFO", self, self.updateServerInfo);
	self:addLuaEvent("TIME_SPACE_RACE_TIMES", self, self.updateFightTimes);
	self:addLuaEvent("TIME_SPACE_RACE_FIGHT", self, self.onFight);
	self:addLuaEvent("TIME_SPACE_FIGHT_CHECK", self, self.onFightCheck);

	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
	self.roleInfoPanel:setRectAnchor(1);

	self.rewardRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.TimeSpaceRace_Reward);
	self.rewardRedPoint:setRectAnchor(1);
	self.rewardRedPoint:setLocation(330, -313);

	local list = DataCenter.timeSpaceRaceUtil.timeSpaceList;
	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.buttonList:setRectAnchor(7);
	self.buttonList:setLocation(0, 154, 0);
	self.buttonList:setButtonCell(Lua_TimeSpaceRaceTypeItem);
	self.buttonList:setButtonItem(233, 80);
	self.buttonList:setClickCallBack(self, self.onButtonClick);
	self.buttonList:setData(list);
	if DataCenter.timeSpaceRaceData.spaceType == 0 then
		self.buttonList:setSelected(self.spaceType);
	end

	self.btnBg.clickScale = false;
	self.btnBg:addClickFuntion(self, self.onMaskClick);
	self.bottomBg.clickScale = false;
	self.bottomBg:addClickFuntion(self, self.onMaskClick);
	self.checkRecord:addClickFuntion(self, self.onCheckRecord);
	self.checkRank:addClickFuntion(self, self.onCheckRank);
	self.btnLineup:addClickFuntion(self, self.onLineup);
	self.checkReward:addClickFuntion(self, self.onCheckReward);
	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.btnMopup:addClickFuntion(self, self.onMopup);
	self.btnRefresh:setEnable(false);
	self.btnRefresh:addClickFuntion(self, self.onRefresh);

	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sWinInfo(0);
end

function Lua_TimeSpaceRaceWindow:dispose()
	DataCenter.preLoadData:removeBySign("Lua_TimeSpaceRaceLineupWindow", self, self.onAttackLineupShow);
	DataCenter.preLoadData:removeBySign("Lua_HeroLineupWindow", self, self.onDefendLineupShow);
	DataCenter.sceneUtil:setSceneDataExtendVal(self.windowName, "FurEffShow", false);
	self:stopTimer();
	if self.roleInfoPanel then
		self.roleInfoPanel:dispose();
		self.roleInfoPanel = nil;
	end
	if self.buttonList then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	if self.btnInfo then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	if self.sceceEff then
		self.sceceEff:dispose();
		self.sceceEff = nil;
	end
	self.data = nil;
	self.msg = nil;
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceWindow:onBackBtnClick()
	DataCenter.funcPathUtil:gotoFunction(1038, true);
end

function Lua_TimeSpaceRaceWindow:resetActive(bActive)
	self:superCall("resetActive", bActive);
	if bActive then
		self:updateDragPos();
	end
end

function Lua_TimeSpaceRaceWindow:onWinSceneShow(sceneId)
	self:superCall("onWinSceneShow", sceneId);
	if self.prevSceneId ~= self.winSceneId then
		Scene3DManager.instance:destroyScene(self.prevSceneId, 0);
	end

	if self.spaceType ~= self.data.id then
		Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sWinInfo(self.data.id);
	end
	self.spaceType = self.data.id;
end

function Lua_TimeSpaceRaceWindow:onWinSceneLoaded(sceneId)
	self:superCall("onWinSceneLoaded", sceneId);
	self:updateDragPos();
end

function Lua_TimeSpaceRaceWindow:onButtonClick(index, data)
	self.targetIdx = nil;
	self.data = data;

	self.titleIcon:setAltas("time_space_atlas", data.name_sprite);
	self.prevSceneId = self.winSceneId;
	self:setWinSceneId(data.scene_id);
end

function Lua_TimeSpaceRaceWindow:showSceneEff()
	if self.sceceEff == nil then
		self.sceceEff = ModelEffComponent(self.winSceneId, 0)
		self.sceceEff:setUrl("/effects/scsEffects/xuanwo_01", "xuanwo_01", "xuanwo_01")
	else
		-- if self.sceceEffId ~= self.winSceneId then
		-- 	self.sceceEff:setSceneInfo(self.winSceneId, 0)
		-- end
		self.sceceEff:setEnable(false);
		self.sceceEff:setEnable(true);
	end
end

function Lua_TimeSpaceRaceWindow:updateServerInfo(msg)
	self.msg = msg;
	if msg == nil or not DataCenter.roleData:checkInTime(msg.start_tick, msg.end_tick) then
		self.bRace = false;
		self:showUnOpen(true);
		self.buttonList:setSelected(msg.type);
		self.btnRefresh:setEnable(false);
	else
		self.bRace = true;
		self:showUnOpen(false);
		if msg.type == 0 then
			self.buttonList:setSelected(1);
			Lua_WindowUtil.openWin("Lua_TimeSpaceChooseWindow", Lua_WinParam.ACTION_OPEN);
		else
			self.spaceType = msg.type;
			self.buttonList:setSelected(msg.type);
		end
		self.btnRefresh:setEnable(self.spaceType == DataCenter.timeSpaceRaceData.spaceType);
	end
	self:updateEnemyList();
	self:updateFightTimes(msg);
	if msg.his_rank > 0 then
		self.maxRankText.text = LanUtil.formateStr(770007, tostring(msg.his_rank));
	else
		self.maxRankText:setLangValue(770023);
	end

	if self.bRace then
		self.leftTime = tonumber(msg.end_tick) - DataCenter.roleData.serverTime;
		self.timeText.text = LanUtil.formateStr(770003, Lua_TimeTransform.transSeconds20(self.leftTime));
	else
		self.leftTime = tonumber(msg.start_tick) - DataCenter.roleData.serverTime;
		self.timeText.text = LanUtil.formateStr(770002, Lua_TimeTransform.transSeconds20(self.leftTime));
	end

	self:startTimer();
end

function Lua_TimeSpaceRaceWindow:showUnOpen(bValue)
	if bValue then
		if self.upOpenBg == nil then
			self.upOpenBg = UICreate.createUIAtlasImage(self.content, "time_space_atlas", "xui_jmd_widget_20", 0, 4.5, 714, 144);

			self.upOpenText = UICreate.createLabel(self.content, nil, 0, 0, 100, 31, 26);
			self.upOpenText.pivotValue = 4;
			self.upOpenText.lineSpacing = 1.5;
			self.upOpenText.alignmentValue = 4;
			self.upOpenText.horizontalOverflowValue = 1;
			self.upOpenText.verticalOverflowValue = 1;
			self.upOpenText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
			self.upOpenText.effectStyle = 2;
			self.upOpenText.effectColorStr = Lua_ColorDefine.transColor("000000");
			self.upOpenText:setEffectDistance(2, 2);
			self.upOpenText:setLangValue(770001);
		end
		self.upOpenBg:setEnable(true);
		self.upOpenText:setEnable(true);
	else
		if self.upOpenBg then
			self.upOpenBg:setEnable(false);
			self.upOpenText:setEnable(false);
		end
	end
end

function Lua_TimeSpaceRaceWindow:updateEnemyList()
	local arr = DataCenter.timeSpaceRaceData:initEnemyList();
	local dataLen = arr:getSize();
	if dataLen >= 20 then
		self.dragHeight = dataLen * 780;
	elseif dataLen > 10 then
		self.dragHeight = dataLen * 750;
	else
		self.dragHeight = dataLen * 630;
	end
	self.dragHeight = self.dragHeight - self.adaptHeight * 2;
	-- print(dataLen, self.dragHeight)

	local selfIdx;
	for i = 1, dataLen do
		if DataCenter.roleData:isMyself(arr[i]) then
			selfIdx = i;
			break;
		end
	end
	selfIdx = selfIdx or 1;
	self:updateDragPos(selfIdx);

	local maxLen = dataLen > self.modelLen and dataLen or self.modelLen;
	local uniqueId;
	local info;
	local dressId;
	local dressVo;
	local thing;
	local data;
	for i = 1, maxLen do
		uniqueId = self.winSceneId * 1000 + i;
		if i > dataLen then
			if ThingUtil.instance:hasThingById(self.winSceneId, 0, uniqueId) then
				ThingUtil.instance:hidePlayer(self.winSceneId, 0, uniqueId);
			end
		else
			info = DataCenter.timeSpaceRaceData:getEnemyInfo(arr[i]);
			dressId = DataCenter.roleData:getDressUpId(Lua_DressUpDefine.MAINTYPE_MODEL, info.show_role.dress_info);
			dressVo = DataCenter.roleUtil:getDressUpVoById(dressId);
			if dressVo.bShowFur then
				DataCenter.sceneUtil:setSceneDataExtendVal(self.windowName, "FurEffShow", true);
			end
			thing = DataCenter.thingData:getThingPlayer(self.winSceneId, 0, uniqueId);
			posX, posY, posZ, scale = self:getPosByIdx(i);
			if thing == nil then
				data = self:getModelData(uniqueId, arr[i], posX, posY, posZ, scale, dressVo);
				ThingUtil.instance:addTimeSpaceRacePlayer(data);
			-- elseif thing.bLoadCompleted then
			else
				thing.objId = arr[i];
				thing:updateData();
				thing.data.objId = arr[i];
				thing.player:setPosPoint(posX, posY, posZ, true);
				thing.data.scaleX = scale;
				thing.data.scaleY = scale;
				thing.data.scaleZ = scale;
				thing.data.modelFloder = dressVo.floder;
				thing.data.modelFile = dressVo.uiModelSrc;
				thing.data.modelName = dressVo.uiModelAvatarName;
				-- thing.player:resetBodyUrl();
				thing.player:loadBody();
				thing.player:checkLoadRes();
				ThingUtil.instance:showPlayer(self.winSceneId, 0, uniqueId);
			-- else
			-- 	data = self:getModelData(uniqueId, arr[i], posX, posY, posZ, scale, dressVo);
			-- 	thing.player.data = data;
			-- 	thing.player:resetBodyUrl();
			-- 	thing.player:loadBody();
			-- 	thing.player:checkLoadRes();
			end
		end
	end
	self.modelLen = maxLen;
end

function Lua_TimeSpaceRaceWindow:getModelData(roleId, objId, posX, posY, posZ, scale, dressVo)
	local data = TimeSpaceRaceData();
	data.layer = Lua_ThingDefine.UI_MODEL_LAYER;
	data.isShowName = true;
	data.isShowHpBar = false;
	data.isShowBuffIcon = false;
	data.canBeClick = true;
	data.roleId = roleId;
	data.objId = objId;
	data.formationPos = 0;
	data.campPosId = 0;
	data.standType = 0;
	data.sceneId = self.winSceneId;
	data.dir = -90;
	data.canDrag = false;
	data.showShadow = true;
	data.bPlanarShadow = true;
	data.toLand = false;
	data.isUIHeadInfo = true;
	data.shenbingId = 0;
	data.px = posX;
	data.py = posY;
	data.pz = posZ;
	data.scaleX = scale;
	data.scaleY = scale;
	data.scaleZ = scale;
	data.modelFloder = dressVo.floder;
	data.modelFile = dressVo.uiModelSrc;
	data.modelName = dressVo.uiModelAvatarName;
	return data;
end

function Lua_TimeSpaceRaceWindow:getPosByIdx(index)
	local value = self.dragHeight / 2 - 200;
	if index == 1 then
		return 0, 0, value + 1100, 1.2;
	elseif index == 2 then
		return -110, 0, value - 800, 1;
	elseif index == 3 then
		return 110, 0, value - 800, 1;
	else
		if index % 2 == 0 then
			return -125, 0, (value - 2630) + (index - 4) * -880, 1;
		else
			return 125, 0, (value - 2130) + (index - 4) * -880, 1;
		end
	end
end

function Lua_TimeSpaceRaceWindow:updateDragPos(targetIdx)
	if self.dragHeight == nil or (targetIdx == nil and self.targetIdx == nil) then
		return;
	end
	targetIdx = targetIdx or self.targetIdx;
	local config = Lua_SceneConfigData.getSceneConfig(self.winSceneId);
	local dragCenterPos = config.dragCenterPos;
	local _areaWidth = 0;
	local _areaHeight = self.dragHeight / config.dragRate;
	local vec = self.dragVec or Vector3.zero;
	if targetIdx ~= self.targetIdx then
		local posX, posY, posZ = self:getPosByIdx(targetIdx);
		vec:Set(posX * 0.01, posY * 0.01, posZ * 0.01);

		local cam = GlobalVar.mainCamera;
		local r = cam.transform.right;
		local f = Vector3.Cross(Vector3.up, r).normalized;
		local dragRate = config.dragRate * 0.01;
		local x = (dragCenterPos.x - vec.x) / dragRate;
		local y = (dragCenterPos.y - vec.y) / dragRate;
		local z = (dragCenterPos.z - vec.z) / dragRate;
		vec:Set(x, y, z);

		local _areaWidthHalf = _areaWidth / 2;
		local _areaHeightHalf = _areaHeight / 2;
		x = _areaWidth <= 0 and 0 or (vec.x * f.z - vec.z * f.x) / (r.x * f.z - r.z * f.x);
		y = _areaHeight <= 0 and 0 or (vec.x * r.z - vec.z * r.x) / (f.x * r.z - f.z * r.x);
		x = x < -_areaWidthHalf and -_areaWidthHalf or x;
		x = x > _areaWidthHalf and _areaWidthHalf or x;
		y = y < -_areaHeightHalf and -_areaHeightHalf or y;
		y = y > _areaHeightHalf and _areaHeightHalf or y;
		x = x * dragRate;
		y = y * dragRate;
		r = Vector3(r.x * x, r.y * x, r.z * x);
		f = Vector3(f.x * y, f.y * y, f.z * y);
		vec:Set(dragCenterPos.x - r.x + f.x, dragCenterPos.y, dragCenterPos.z - r.z + f.z);
	end
	self.dragVec = vec;
	self.targetIdx = targetIdx;

	LuaUtil.updateMapDragInfo(dragCenterPos.x, dragCenterPos.y, dragCenterPos.z, _areaWidth, _areaHeight, config.dragRate, vec.x, vec.y, vec.z);
end

function Lua_TimeSpaceRaceWindow:updateFightTimes(msg)
	self.left_fight_times = msg.left_fight_times;
	self.left_buy_times = msg.left_buy_times;

	local str = tostring(msg.left_fight_times);
	if msg.left_fight_times > 0 then
		str = Lua_ColorDefine.getColorStr("6DF473", str);
	else
		str = Lua_ColorDefine.getColorStr("ED4C30", str);
	end
	self.fightTimesText.text = LanUtil.formateStr(770005, str);

	str = tostring(msg.left_buy_times);
	if msg.left_buy_times > 0 then
		str = Lua_ColorDefine.getColorStr("6DF473", str);
	else
		str = Lua_ColorDefine.getColorStr("ED4C30", str);
	end
	self.leftBuyText.text = LanUtil.formateStr(770006, str);
end

function Lua_TimeSpaceRaceWindow:startTimer()
	if not self.bTimer then
		self.bTimer = true;
		self:addTimer("Lua_TimeSpaceRaceWindow", 1, self, self.onTimer);
	end
end

function Lua_TimeSpaceRaceWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_TimeSpaceRaceWindow:onTimer()
	if self.bRace then
		self.leftTime = tonumber(self.msg.end_tick) - DataCenter.roleData.serverTime;
		self.timeText.text = LanUtil.formateStr(770003, Lua_TimeTransform.transSeconds20(self.leftTime));
	else
		self.leftTime = tonumber(self.msg.start_tick) - DataCenter.roleData.serverTime;
		self.timeText.text = LanUtil.formateStr(770002, Lua_TimeTransform.transSeconds20(self.leftTime));
	end

	if self.leftTime <= 0 then
		self:stopTimer();
		self.timeText.text = nil;
	end
end

function Lua_TimeSpaceRaceWindow:onFight(playerId)
	self.fightPlayerId = playerId;
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sFightCheck(playerId, 1);
end

function Lua_TimeSpaceRaceWindow:onFightCheck(value)
	if value == 1 then
		local config = DataCenter.timeSpaceRaceUtil:getTimeSpaceConfig(self.spaceType);
		local sceneId = DataCenter.heroLineupData:getLineUpSceneId(config.attack_lineup);
		local param = { playerId = self.fightPlayerId, attackLineup = config.attack_lineup, defendLineup = config.defend_lineup };
		DataCenter.preLoadData:preShowScene("Lua_TimeSpaceRaceLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onAttackLineupShow, param, sceneId, 0);
	end
end

function Lua_TimeSpaceRaceWindow:onAttackLineupShow(param, mp, success)
	if not success then return; end
	Lua_WindowUtil.openWin("Lua_TimeSpaceRaceLineupWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_TimeSpaceRaceWindow:onCheckRecord(go)
	Lua_WindowUtil.openWin("Lua_TimeSpaceFightRecordWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_TimeSpaceRaceWindow:onCheckRank(go)
	Lua_WindowUtil.openWin("Lua_TimeSpaceRaceRankWindow", Lua_WinParam.ACTION_OPEN, self.spaceType);
end

function Lua_TimeSpaceRaceWindow:onLineup(go)
	local config = DataCenter.timeSpaceRaceUtil:getTimeSpaceConfig(self.spaceType);
	local sceneId = DataCenter.heroLineupData:getLineUpSceneId(config.defend_lineup);
	DataCenter.preLoadData:preShowScene("Lua_HeroLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onDefendLineupShow, config.defend_lineup, sceneId, 0);
end

function Lua_TimeSpaceRaceWindow:onDefendLineupShow(param, mp, success)
	if not success then return; end
	Lua_WindowUtil.openWin("Lua_HeroLineupWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_TimeSpaceRaceWindow:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_TimeSpaceRaceRewardWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_TimeSpaceRaceWindow:onCheckHelp(go)
	local config = getConfig("time_space_active_rule");
	Lua_WindowUtil.openWin("Lua_GameplayRulesWindow", Lua_WinParam.ACTION_OPEN, config);
end

function Lua_TimeSpaceRaceWindow:onMopup(go)
	if not self.bRace then
		OperateAlert.showLangValue(770004);
		return;
	end

	if self.left_fight_times > 0 then
		local tipsData = { des = 770027, btnType = 1, owner = self, sureFun = self.onSureMopup };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	elseif self.left_buy_times > 0 then
		Lua_WindowUtil.openWin("Lua_TimeSpaceBuyTimesWindow", Lua_WinParam.ACTION_OPEN);
	else
		OperateAlert.showLangValue(770009);
	end
end

function Lua_TimeSpaceRaceWindow:onSureMopup()
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sMopup();
end

function Lua_TimeSpaceRaceWindow:onRefresh(go)
	if not self.bRace then
		OperateAlert.showLangValue(770004);
		return;
	end

	local value = DataCenter.roleData.serverTime - tonumber(self.msg.last_refresh_tick);
	value = DataCenter.timeSpaceRaceUtil.refreshInterval - value;
	if value > 0 then
		OperateAlert.show(LanUtil.formateStr(770025, tostring(value)));
		return;
	end
	
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sRefresh();
end










Lua_TimeSpaceRaceTypeItem = class("Lua_TimeSpaceRaceTypeItem", Lua_ButtonCell)
function Lua_TimeSpaceRaceTypeItem:ctor(p)
	self:superCall("ctor", p, "TimeSpaceRaceTypeItem_skin");
end

function Lua_TimeSpaceRaceTypeItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bg.clickScale = false;
end

function Lua_TimeSpaceRaceTypeItem:dispose()
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceTypeItem:setData(data)
	self:superCall("setData", data);
	self.bg:setAltas("time_space_atlas", data.bg_sprite);
	local vo = DataCenter.funcOpenUtil:getFuncOpenVoById(data.open_id);
	if vo and not vo.isOpen then
		self.condBg:setEnable(true);
		self.condText:setEnable(true);
		self.condText.text = vo.advanceMessage;
	else
		self.condBg:setEnable(false);
		self.condText:setEnable(false);
	end
end

function Lua_TimeSpaceRaceTypeItem:setCanClick(bCan)
	if bCan == true then
		self.bg.mouseEnable = true;
		self.bg:addClickFuntion(self, self.onPressClick);
	else
		self.bg.mouseEnable = false;
		self.bg:removeClickFuntion(self, self.onPressClick);
	end
end

function Lua_TimeSpaceRaceTypeItem:setSelected(index)
	self:superCall("setSelected", index);
	self.selectBg:setEnable(self.index == index);
end

function Lua_TimeSpaceRaceTypeItem:onPressClick(go)
	if not DataCenter.funcOpenData:isOpened(self.data.open_id, true) then
		return;
	end

	if self.owner and self.callBack then
		self.callBack(self.owner, self.index)
	end
end