Lua_TimeSpaceRaceRankWindow = class("Lua_TimeSpaceRaceRankWindow", Lua_Window)
function Lua_TimeSpaceRaceRankWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_TimeSpaceRaceRankWindow";
	self.skinName = "TimeSpaceRaceRankWindow_skin";
	self.isFullPaving = true;
	self.isFullSizeWin = true;
end

function Lua_TimeSpaceRaceRankWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("TIME_SPACE_RACE_RANK", self, self.updateRankInfo);
	self:addLuaEvent("TIME_SPACE_RACE_LIKE", self, self.updateRankLike);
	self:addLuaEvent("TIME_SPACE_RACE_RANK_LIKE", self, self.onLike);

	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
	self.roleInfoPanel:setRectAnchor(1);

	self.rankArr = Array();

	self.topPos = {{2, -230}, {-235, -290}, {236, -290}};
	self.topArr = Array();
	local item
	for i = 1, 3 do
		item = Lua_TimeSpaceRaceRankTopItem.new(self.content);
		item.contentName = "topRank_"..i;
		item:setRectAnchor(1);
		item:setLocation(self.topPos[i][1], self.topPos[i][2], 0);
		item:setRank(i);
		self.topArr:add(item);
	end

	self.itemList = Lua_DragList.new(self.content, 688, 540 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -175, 0);
	self.itemList.tweenId = 2008;
	self.itemList.delayTween = true;
	self.itemList.callBackOwner = self;
	self.itemList.turnPageCallBack = self.turePage;
	self.itemList:setListCell(Lua_TimeSpaceRaceRankItem, 688, 125, 1);
	self.itemList:setCellSpacing(0, 5);

	self.myAvatarItem = Lua_AvatarItem.new(self.content);
	self.myAvatarItem:setRectAnchor(7);
	self.myAvatarItem:setScale(0.7, 0.7, 1);
	self.myAvatarItem:setLocation(-147, 186, 0);

	self.myRankNum = Lua_NumberImage.new(self.content);
	self.myRankNum:setRectAnchor(7);
	self.myRankNum:setLocation(-270.5, 186, 0);
	self.myRankNum.numOffsetX = -4;
	self.myRankNum.numAtlas = "number";
	self.myRankNum.preStr = "xui_phb_number_";

	local arr = DataCenter.timeSpaceRaceUtil.rankList;
	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.buttonList:setRectAnchor(7);
	self.buttonList:setRectPivot(5);
	self.buttonList.pivot = -1;
	self.buttonList:setLocation(360, 53.5, 0);
	self.buttonList:setButtonStyle("common_altas_1", "ui_common_button_001_b", "ui_common_button_001_b", 118, 108, 0.01, 1);
	self.buttonList:setButtonLine("common_altas_1", "ui_common_line_011", 2, 108, 0, 0, 1);
	self.buttonList:setButtonItem(120, 108);
	self.buttonList:setRedPoint(40, 40);
	self.buttonList:setClickCallBack(self, self.onButtonClick);
	self.buttonList:setData(arr);

	self.topBg.clickScale = false;
	self.topBg:addClickFuntion(self, self.onMaskClick);
	self.listBg.clickScale = false;
	self.listBg:SetDimensions(720, 563 + self.adaptHeight);
	self.listBg:addClickFuntion(self, self.onMaskClick);
	self.myBtnLike:addClickFuntion(self, self.onLikeClick);

	self:startTimer();
	self:onTimer();
end

function Lua_TimeSpaceRaceRankWindow:dispose()
	self:stopTimer();
	if self.roleInfoPanel then
		self.roleInfoPanel:dispose();
		self.roleInfoPanel = nil;
	end
	if self.buttonList then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	if self.btnInfo then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.myAvatarItem then
		self.myAvatarItem:dispose();
		self.myAvatarItem = nil;
	end
	if self.myRankNum then
		self.myRankNum:dispose();
		self.myRankNum = nil;
	end
	if self.topArr then
		self.topArr:dispose();
		self.topArr:clear();
		self.topArr = nil;
	end
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceRankWindow:showWin(param)
	self:superCall("showWin", param);
	self.buttonList:setSelected(param);
end

function Lua_TimeSpaceRaceRankWindow:onScreenResize()
	self:superCall("onScreenResize")
	self.listBg:SetDimensions(720, 563 + self.adaptHeight);
	self.itemList:setContentRect(708, 540 + self.adaptHeight);
end

function Lua_TimeSpaceRaceRankWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_TimeSpaceRaceRankWindow", 1, self, self.onTimer);
	end
end

function Lua_TimeSpaceRaceRankWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_TimeSpaceRaceRankWindow:onTimer()
	local remainTime = DataCenter.timeSpaceRaceData.endTick - DataCenter.roleData.serverTime;
	if remainTime > 0 then
		self.timeText:setEnable(true);
		self.timeText.text = LanUtil.formateStr(770030, Lua_TimeTransform.transSeconds1(remainTime));
	else
		self:stopTimer();
		self.timeText:setEnable(false);
	end
end

function Lua_TimeSpaceRaceRankWindow:onButtonClick(index, data)
	self.spaceType = index;
	self.nameText.text = data.name;

	for i = 1, 3 do
		self.topArr[i]:setEnable(false);
		self.topArr[i]:setLocation(self.topPos[i][1], self.topPos[i][2], 0);
	end
	self.itemList.showTween = true;
	self.itemList.isPageEnd = false;

	self.bRefresh = true;
	self:turePage(0);
end

function Lua_TimeSpaceRaceRankWindow:turePage(page)
	page = page or 1
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sRankInfo(self.spaceType, page);
end

function Lua_TimeSpaceRaceRankWindow:updateRankInfo(msg)
	self:updateLikeTimes(msg.left_praise_times);

	if self.bRefresh then
		local len = self.rankArr:getSize();
		local num = len - #msg.role_list;
		while (num > 0) do
			self.rankArr:remove();
			num = num - 1;
		end
		for i = 1, #msg.role_list do
			if i > len then
				self.rankArr:add(msg.role_list[i]);
			else
				self.rankArr[i] = msg.role_list[i];
			end
		end
	else
		for i = 1, #msg.role_list do
			self.rankArr:add(msg.role_list[i]);
		end
	end
	self.itemList.isPageEnd = (msg.is_end == 1);
	self:updateRankList();
	self:updateTopRank();
	self.bRefresh = false;
	
	local info = msg.self_rank;
	if info == nil then
		self.myNoneRankSp:setEnable(true);
		self.myNameTxt:setEnable(false);
		self.myForceTxt:setEnable(false);
		self.myRankNum:setEnable(false);
		self.myAvatarItem:init();
	else
		if info.rank < 1 then
			self.myNoneRankSp:setEnable(true);
			self.myRankNum:setEnable(false);
		else
			self.myNoneRankSp:setEnable(false);
			self.myRankNum:setEnable(true);
			self.myRankNum.num = info.rank;
		end

		self.myNameTxt:setEnable(true);
		self.myNameTxt.text = info.show_role.name;
		
		self.myAvatarItem:setRoleId(info.id);
		self.myAvatarItem:setRoleDressUp(info.show_role.dress_info, true);
		self.myAvatarItem:setRoleLevel2(info.show_role.level);

		self.myForceTxt:setEnable(true);
		self.myForceTxt.text = spliceIconStr("number", "xui_zl1_number_10", 29, 31).." "..info.show_role.force;

		self.myLikeTxt.text = info.praise_num;
	end
end

function Lua_TimeSpaceRaceRankWindow:updateRankLike(msg)
	self:updateLikeTimes(msg.left_praise_times);
	for i = 1, self.rankArr:getSize() do
		if self.rankArr[i].id == msg.role_info.id then
			self.rankArr[i] = msg.role_info;
			break;
		end
	end
	self:updateRankList();
	self:updateTopRank();
end

function Lua_TimeSpaceRaceRankWindow:updateLikeTimes(times)
	self.left_praise_times = times;
	local limitTimes = DataCenter.timeSpaceRaceUtil.limitLikeTimes;
	self.leftLikeText.text = LanUtil.formateStr(303013, tostring(times), tostring(limitTimes))
end

function Lua_TimeSpaceRaceRankWindow:updateRankList()
	local len = self.rankArr:getSize() - 3;
	if len > 0 then
		self.itemList:setEnable(true);
		self.itemList:setArrayData(self.rankArr, 4);
		if self.bRefresh then
			self.itemList:moveToIndex(1, true);
		end
		self:showNone(false);
	else
		self.itemList:setEnable(false);
		self:showNone(true);
	end
end

function Lua_TimeSpaceRaceRankWindow:showNone(value)
	if value then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createImage(self.content, "/images/championship/xui_jys_widget_18.png", 0, -170, 0, 0);

			self.noneText = UICreate.createLabel(self.content, nil, 1.5, -220, 100, 40, 36);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("7A6C74");
			self.noneText:setLangValue(202502);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end

function Lua_TimeSpaceRaceRankWindow:updateTopRank()
	for i = 1, 3 do
		self.topArr[i]:setData(self.rankArr[i]);
	end
	self:updateTween();
end

function Lua_TimeSpaceRaceRankWindow:updateTween()
	if not self.bRefresh then
		return
	end
	
	if self.tweenName then
		DataCenter.winTweenManager:removeWinTween(self.tweenName)
	end
	self.tweenName = DataCenter.winTweenManager:createWinTween(self.windowName, self.windowObj.transform);
end

function Lua_TimeSpaceRaceRankWindow:onLike(data)
	if DataCenter.roleData:isMyself(data.id) then
		OperateAlert.showLangValue(202540);
		return;
	end
	if self.left_praise_times and self.left_praise_times <= 0 then
		OperateAlert.showLangValue(202541);
		return;
	end
	if data.is_praised == 1 then
		OperateAlert.showLangValue(202542);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sRankLike(self.spaceType, data.id);
end

function Lua_TimeSpaceRaceRankWindow:onLikeClick(go)
	OperateAlert.showLangValue(202540);
end










Lua_TimeSpaceRaceRankTopItem = class("Lua_TimeSpaceRaceRankTopItem", Lua_DisplayObject)
function Lua_TimeSpaceRaceRankTopItem:ctor(p)
	self:superCall("ctor", p, "TimeSpaceRaceRankTopItem_skin");
end

function Lua_TimeSpaceRaceRankTopItem:buildShowItem()
	self:superCall("buildShowItem");
	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setCanClick(true);

	self.btnLike:addClickFuntion(self, self.onLikeClick);
end

function Lua_TimeSpaceRaceRankTopItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceRankTopItem:setRank(value)
	self.bg:setAltas("rank_altas", "xui_phb_bg_"..(value + 1));
	self.rankText.text = LanUtil.formateStr(202538, convert_arab_to_chinese(value));
	if value == 1 then
		self.rankText:setLocation(0, 26, 0);
		self.rankText.fontSize = 30;
		self.rankText.colorStr = Lua_ColorDefine.transColorStr("FCF6AF");

		self.nameText:setLocation(0, -26, 0);
		self.nameText.fontSize = 30;
		self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A");

		self.forceTxt:setLocation(0, -68, 0);
		self.forceTxt.colorStr = Lua_ColorDefine.transColor("FFFFFF");
		self.forceTxt.effectColorStr = Lua_ColorDefine.transColorStr("876A2A");

		self.btnLike:setLocation(0, -110, 0);
		self.likeNumTxt:setLocation(-20, -106, 0);

		self.avatarItem:setScale(0.9, 0.9, 1);
		self.avatarItem:setLocation(0, 108, 0);
	else
		self.rankText:setLocation(0, 28, 0);
		self.rankText.fontSize = 26;
		self.rankText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");

		self.nameText:setLocation(0, -13, 0);
		self.nameText.fontSize = 26;
		
		self.forceTxt:setLocation(0, -48, 0);
		self.forceTxt.colorStr = Lua_ColorDefine.transColor("FFFFFF");
		if value == 2 then
			self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("606A93");
			self.forceTxt.effectColorStr = Lua_ColorDefine.transColorStr("606A93");
		else
			self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A");
			self.forceTxt.effectColorStr = Lua_ColorDefine.transColorStr("876A2A");
		end

		self.btnLike:setLocation(0, -85, 0);
		self.likeNumTxt:setLocation(-20, -80, 0);

		self.avatarItem:setScale(0.8, 0.8, 1);
		self.avatarItem:setLocation(0, 96, 0);
	end
end

function Lua_TimeSpaceRaceRankTopItem:setData(data)
	self.data = data
	if data == nil then
		self.nameText:setLangValue(202500);
		self.forceTxt:setEnable(false);
		self.btnLike:setEnable(false);
		self.likeNumTxt:setEnable(false);
		self.avatarItem:init();
	else
		-- if data.type == 1 then
			self.nameText.text = data.show_role.name;
		-- else
		-- 	self.nameText.text = LanUtil.formateStr(10051, data.show_role.server_prev, data.show_role.name);
		-- end
		self.forceTxt:setEnable(true);
		self.forceTxt.text = spliceIconStr("number", "xui_zl1_number_10", 29, 31).." "..data.show_role.force;

		self.btnLike:setEnable(true);
		self.likeNumTxt:setEnable(true);
		self.likeNumTxt.text = data.praise_num;

		self.avatarItem:setRoleId(data.id, data.show_role.server_flag, data.type);
		self.avatarItem:setRoleDressUp(data.show_role.dress_info, true);
		self.avatarItem:setRoleLevel2(data.show_role.level);
	end
end

function Lua_TimeSpaceRaceRankTopItem:onLikeClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("TIME_SPACE_RACE_RANK_LIKE", self.data);
end










Lua_TimeSpaceRaceRankItem = class("Lua_TimeSpaceRaceRankItem", Lua_ListCell)
function Lua_TimeSpaceRaceRankItem:ctor(p)
	self:superCall("ctor", p, "TimeSpaceRaceRankItem_skin");
end

function Lua_TimeSpaceRaceRankItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.7, 0.7, 1);
	self.avatarItem:setLocation(-147, 0, 0);

	self.btnLike:addClickFuntion(self, self.onLikeClick);
end

function Lua_TimeSpaceRaceRankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceRankItem:setData(data)
	self.data = data;
	self.numTxt.text = data.rank;
	-- if data.type == 1 then
		self.nameTxt.text = data.show_role.name;
	-- else
	-- 	self.nameTxt.text = LanUtil.formateStr(10051, data.show_role.server_prev, data.show_role.name);
	-- end
	self.forceTxt.text = spliceIconStr("number", "xui_zl1_number_10", 29, 31).." "..data.show_role.force;
	self.likeNumTxt.text = data.praise_num;

	self.avatarItem:setRoleDressUp(data.show_role.dress_info, true);
	self.avatarItem:setRoleLevel2(data.show_role.level);
end

function Lua_TimeSpaceRaceRankItem:onPressClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	if self.avatarItem:checkInBound(winPos.x, winPos.y) then
		if self.data.type > 0 then
			OperateAlert.showLangValue(123657);
			return;
		end

		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.data.id, self.data.show_role.server_flag);
	end
end

function Lua_TimeSpaceRaceRankItem:onLikeClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("TIME_SPACE_RACE_RANK_LIKE", self.data);
end