Lua_TimeSpaceFightDetailsWindow = class("Lua_TimeSpaceFightDetailsWindow", Lua_Window)
function Lua_TimeSpaceFightDetailsWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_TimeSpaceFightDetailsWindow";
	self.skinName = "TimeSpaceFightDetailsWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_TimeSpaceFightDetailsWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 652, 720, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -90, 0);
	self.itemList:setListCell(Lua_TimeSpaceFightDetailsItem, 652, 435, 1);

	self:addLuaEvent("TIME_SPACE_RACE_FIHGT_DETAILS", self, self.updateShowInfo);
end

function Lua_TimeSpaceFightDetailsWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_TimeSpaceFightDetailsWindow:showWin(param)
	self:superCall("showWin", param);
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sFightDetails(param.record_id);

	if DataCenter.roleData:isMyself(param.att_role.id) then
		self.leftName.text = LanUtil.formateStr(10066, param.att_role.server_prev, param.att_role.name);
		if param.is_robot == 1 then
			self.rightName.text = param.def_role.name;
		else
			self.rightName.text = LanUtil.formateStr(10066, param.def_role.server_prev, param.def_role.name);
		end
	else
		if param.is_robot == 1 then
			self.leftName.text = param.def_role.name;
		else
			self.leftName.text = LanUtil.formateStr(10066, param.def_role.server_prev, param.def_role.name);
		end
		self.rightName.text = LanUtil.formateStr(10066, param.att_role.server_prev, param.att_role.name);
	end
end

function Lua_TimeSpaceFightDetailsWindow:updateShowInfo(msg)
	if DataCenter.roleData:isMyself(self.showData.att_role.id) then
		self.resultText.text = LanUtil.formateStr(10050, tostring(msg.att_num), tostring(msg.def_num));
	else
		self.resultText.text = LanUtil.formateStr(10050, tostring(msg.def_num), tostring(msg.att_num));
	end

	local arr = Array();
	local data = msg.fight_report_info;
	local len = data == nil and 0 or #data;
	if len > 1 then
		table.sort(data, function(a, b) return a.rotation < b.rotation end);
	end
	local canDrag = true;
	for i = 1, len do
		if len >= i then
			arr:add({ index = i, info = self.showData, data = data[i] });
		else
			canDrag = false;
			arr:add({ index = i, info = self.showData, data = nil });
		end
	end
	self.itemList:setArrayData(arr);
	self.itemList.canDrag = canDrag;
end










Lua_TimeSpaceFightDetailsItem = class("Lua_TimeSpaceFightDetailsItem", Lua_ListCell)
function Lua_TimeSpaceFightDetailsItem:ctor(p)
	self:superCall("ctor", p,"TimeSpaceFightDetailsItem_skin");
end

function Lua_TimeSpaceFightDetailsItem:buildShowItem()
	self:superCall("buildShowItem")

	self.leftAvatar = Lua_AvatarItem.new(self.showObject);
	self.leftAvatar:setSiblingIndex(1);
	self.leftAvatar:setScale(0.4, 0.4, 1);
	self.leftAvatar:setLocation(-290, 140, 0);
	self.leftAvatar:setRoleAvatar(0);

	self.rightAvatar = Lua_AvatarItem.new(self.showObject);
	self.rightAvatar:setSiblingIndex(2);
	self.rightAvatar:setScale(0.4, 0.4, 1);
	self.rightAvatar:setLocation(290, 140, 0);
	self.rightAvatar:setRoleAvatar(0);

	self.leftPanel = Lua_HeroGridViewPanel.new(self.showObject);
	self.leftPanel:setLocation(-170, -35, 0);
	self.leftPanel:setLayout(1, 2);
	self.leftPanel:setGridCell(70, 70, Lua_TimeSpaceFightDetailsGridItem);
	self.leftPanel:setCanClick(true);

	self.rightPanel = Lua_HeroGridViewPanel.new(self.rightObject);
	self.rightPanel:setLocation(170, -35, 0);
	self.rightPanel:setLayout(1, 0);
	self.rightPanel:setGridCell(70, 70, Lua_TimeSpaceFightDetailsGridItem);
	self.rightPanel:setCanClick(true);

	self.noneText:setEnable(false);
	self.btnPlay:addClickFuntion(self, self.onPlay);
	self.checkHurt:addClickFuntion(self, self.onCheckHurt);
end

function Lua_TimeSpaceFightDetailsItem:dispose()
	if self.leftAvatar then
		self.leftAvatar:dispose();
		self.leftAvatar = nil;
	end
	if self.rightAvatar then
		self.rightAvatar:dispose();
		self.rightAvatar = nil;
	end
	if self.leftPanel then
		self.leftPanel:dispose();
		self.leftPanel = nil;
	end
	if self.rightPanel then
		self.rightPanel:dispose();
		self.rightPanel = nil;
	end
	self.data = nil;
	self:superCall("dispose")
end

function Lua_TimeSpaceFightDetailsItem:setData(data)
	self.data = data
	if data.data == nil then
		self.showObject:SetActive(false);
		self.noneText:setEnable(true);
		self.noneText.text = LanUtil.formateStr(770011, convert_arab_to_chinese(data.index));
	else
		self.showObject:SetActive(true);
		self.noneText:setEnable(false);

		local info = data.info;
		local msg = data.data;

		local maxRound = Lua_FightTemplateConfigData.getConfigData(Lua_FightDefine.TEMPLATE_ID_PEAKDUEL).maxRound;
		self.show_round.text = LanUtil.formateStr(10044, tostring(msg.round), tostring(maxRound));

		self.match_time.text = os.date("%Y-%m-%d %H:%M", tonumber(info.fight_tick));
		if DataCenter.roleData:isMyself(info.att_role.id) then
			if msg.win_id == 1 then
				self.left_result:setAltas("common_altas_4", "xui_jys_label_1");
				self.right_result:setAltas("common_altas_4", "xui_jys_label_2");
			else
				self.left_result:setAltas("common_altas_4", "xui_jys_label_2");
				self.right_result:setAltas("common_altas_4", "xui_jys_label_1");
			end

			self.left_team.text = LanUtil.formateStr(202955, tostring(msg.att_index));
			local role = info.att_role;
			self.leftAvatar:setRoleId(role.id, role.server_flag);
			self.leftAvatar:setRoleDressUp(role.dress_info);
			self.left_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);

			self.left_force.text = msg.att_force;
			self.leftPanel:setDataByProto(msg.att_lineup);

			self.left_bar:setMaxValue(100);
			self.left_bar:setValue(msg.att_health);
			self.left_bar:setText(LanUtil.formateStr(10057, tostring(msg.att_health)));

			self.right_team.text = LanUtil.formateStr(202955, tostring(msg.def_index));
			role = info.def_role;
			self.rightAvatar:setRoleId(role.id, role.server_flag, info.is_robot);
			self.rightAvatar:setRoleDressUp(role.dress_info);
			if info.is_robot == 1 then
				self.right_name.text = role.name;
			else
				self.right_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);
			end

			if msg.def_lineup and #msg.def_lineup > 0 then
				self.rightObject:SetActive(true);
				self.rightNoneText:setEnable(false);

				self.right_force.text = msg.def_force;
				self.right_force:resetSize();
				self.rightForceIcon:setLocation(315 - self.right_force.width - 5, -193, 0);
				self.rightPanel:setDataByProto(msg.def_lineup);

				self.right_bar:setMaxValue(100);
				self.right_bar:setValue(msg.def_health);
				self.right_bar:setText(LanUtil.formateStr(10057, tostring(msg.def_health)));
			else
				self.rightObject:SetActive(false);
				self.rightNoneText:setEnable(true);
			end
		else
			if msg.win_id == 1 then
				self.left_result:setAltas("common_altas_4", "xui_jys_label_2");
				self.right_result:setAltas("common_altas_4", "xui_jys_label_1");
			else
				self.left_result:setAltas("common_altas_4", "xui_jys_label_1");
				self.right_result:setAltas("common_altas_4", "xui_jys_label_2");
			end

			self.left_team.text = LanUtil.formateStr(202955, tostring(msg.def_index));
			local role = info.def_role;
			self.leftAvatar:setRoleId(role.id, role.server_flag);
			self.leftAvatar:setRoleDressUp(role.dress_info);
			self.left_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);

			self.left_force.text = msg.def_force;
			self.leftPanel:setDataByProto(msg.def_lineup);

			self.left_bar:setMaxValue(100);
			self.left_bar:setValue(msg.def_health);
			self.left_bar:setText(LanUtil.formateStr(10057, tostring(msg.def_health)));

			self.right_team.text = LanUtil.formateStr(202955, tostring(msg.att_index));
			role = info.att_role;
			self.rightAvatar:setRoleId(role.id, role.server_flag);
			self.rightAvatar:setRoleDressUp(role.dress_info);
			self.right_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);

			if msg.att_lineup and #msg.att_lineup > 0 then
				self.rightObject:SetActive(true);
				self.noneText:setEnable(false);

				self.right_force.text = msg.att_force;
				self.right_force:resetSize();
				self.rightForceIcon:setLocation(315 - self.right_force.width - 5, -193, 0);
				self.rightPanel:setDataByProto(msg.att_lineup);

				self.right_bar:setMaxValue(100);
				self.right_bar:setValue(msg.att_health);
				self.right_bar:setText(LanUtil.formateStr(10057, tostring(msg.att_health)));
			else
				self.rightObject:SetActive(false);
				self.noneText:setEnable(true);
			end
		end
	end
end

function Lua_TimeSpaceFightDetailsItem:onPlay(go)
	if self.data == nil or self.data.data == nil then
		return
	end
	local data = self.data.data;
	if data.def_lineup == nil and #data.def_lineup < 0 then
		OperateAlert.show(LanUtil.formateStr(770011, convert_arab_to_chinese(data.def_index)));
		return;
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(data.record_id, 0, "", data.rotation, 8);
end

function Lua_TimeSpaceFightDetailsItem:onCheckHurt(go)
	if self.data == nil or self.data.data == nil then
		return
	end
	local data = self.data.data;
	if data.def_lineup == nil and #data.def_lineup < 0 then
		OperateAlert.show(LanUtil.formateStr(770011, convert_arab_to_chinese(data.def_index)));
		return;
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightHurtCollect(data.record_id, 8);
end










Lua_TimeSpaceFightDetailsGridItem = class("Lua_TimeSpaceFightDetailsGridItem", Lua_HeroGridViewItem)
function Lua_TimeSpaceFightDetailsGridItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_TimeSpaceFightDetailsGridItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bg:setScale(0.9, 0.9, 1);
end

function Lua_TimeSpaceFightDetailsGridItem:setData(dataType, data)
	self:superCall("setData", dataType, data);
	if self.itemIcon then
		self.itemIcon:setScale(0.54, 0.54, 1);
	end
end