Lua_TimeSpaceFightRecordWindow = class("Lua_TimeSpaceFightRecordWindow", Lua_Window)
function Lua_TimeSpaceFightRecordWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_TimeSpaceFightRecordWindow";
	self.skinName = "TimeSpaceFightRecordWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_TimeSpaceFightRecordWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("TIME_SPACE_RACE_FIHGT_RECORD", self, self.updateShowInfo);
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sFightRecord();
end

function Lua_TimeSpaceFightRecordWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_TimeSpaceFightRecordWindow:updateShowInfo(msg)
	if msg == nil or msg.record_list == nil or #msg.record_list <= 0 then
		self:showNone(true);
		if self.itemList then
			self.itemList:setEnable(false);
		end
	else
		self:showNone(false);
		if self.itemList == nil then
			self.itemList = Lua_DragList.new(self.content, 630, 735, Lua_AxisDefine.Vertical);
			self.itemList:setLocation(0, -60, 0);
			self.itemList:setListCell(Lua_TimeSpaceFightRecordItem, 630, 228, 1);
			self.itemList:setCellSpacing(0, 5);
		end
		self.itemList:setEnable(true);
		self.itemList:setArrayData(msg.record_list);
		self.itemList:moveToIndex(1, true);
	end
end

function Lua_TimeSpaceFightRecordWindow:showNone(bValue)
	if bValue then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -60, 0, 0);
			self.noneText = UICreate.createLabel(self.content, nil, 0, -91.5, 100, 40, 40);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
			self.noneText:setLangValue(770010);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end










Lua_TimeSpaceFightRecordItem = class("Lua_TimeSpaceFightRecordItem", Lua_ListCell)
function Lua_TimeSpaceFightRecordItem:ctor(p)
	self:superCall("ctor", p, "TimeSpaceFightRecordItem_skin");
end

function Lua_TimeSpaceFightRecordItem:buildShowItem()
	self:superCall("buildShowItem")

	self.leftAvatar = Lua_AvatarItem.new(self.content);
	self.leftAvatar:setSiblingIndex(1);
	self.leftAvatar:setScale(0.7, 0.7, 1);
	self.leftAvatar:setLocation(-255, 10, 0);
	self.leftAvatar:setRoleAvatar(0);

	self.rightAvatar = Lua_AvatarItem.new(self.content);
	self.rightAvatar:setSiblingIndex(2);
	self.rightAvatar:setScale(0.7, 0.7, 1);
	self.rightAvatar:setLocation(255, 10, 0);
	self.rightAvatar:setRoleAvatar(0);

	self.checkDetails:addClickFuntion(self,self.onCheckDetails);
end

function Lua_TimeSpaceFightRecordItem:dispose()
	if self.leftAvatar then
		self.leftAvatar:dispose();
		self.leftAvatar = nil;
	end
	if self.rightAvatar then
		self.rightAvatar:dispose();
		self.rightAvatar = nil;
	end
	self.data = nil;
	self:superCall("dispose")
end

function Lua_TimeSpaceFightRecordItem:setData(data)
	self.data = data

	if DataCenter.roleData:isMyself(data.att_role.id) then
		if data.is_win == 1 then -- 1：攻方 2：守方
			self.left_bg:setAltas("time_space_atlas", "xui_skzb_widget_19");
			self.right_bg:setAltas("time_space_atlas", "xui_skzb_widget_20");
			self.left_result:setAltas("common_altas_4", "xui_jys_label_1");
			self.right_result:setAltas("common_altas_4", "xui_jys_label_2");
		else
			self.left_bg:setAltas("time_space_atlas", "xui_skzb_widget_20");
			self.right_bg:setAltas("time_space_atlas", "xui_skzb_widget_19");
			self.left_result:setAltas("common_altas_4", "xui_jys_label_2");
			self.right_result:setAltas("common_altas_4", "xui_jys_label_1");
		end

		local role = data.att_role;
		self.leftAvatar:setRoleId(role.id, role.server_flag);
		self.leftAvatar:setRoleDressUp(role.dress_info);

		self.left_role_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);
		self.left_rank.text = LanUtil.formateStr(770012, tostring(data.att_rank));

		role = data.def_role;
		self.rightAvatar:setRoleId(role.id, role.server_flag, data.is_robot);
		self.rightAvatar:setRoleDressUp(role.dress_info);

		if data.is_robot == 1 then
			self.right_role_name.text = role.name;
		else
			self.right_role_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);
		end
		self.right_rank.text = LanUtil.formateStr(770012, tostring(data.def_rank));
	else
		if data.is_win == 1 then -- 1：攻方 2：守方
			self.left_bg:setAltas("time_space_atlas", "xui_skzb_widget_20");
			self.right_bg:setAltas("time_space_atlas", "xui_skzb_widget_19");
			self.left_result:setAltas("common_altas_4", "xui_jys_label_2");
			self.right_result:setAltas("common_altas_4", "xui_jys_label_1");
		else
			self.left_bg:setAltas("time_space_atlas", "xui_skzb_widget_19");
			self.right_bg:setAltas("time_space_atlas", "xui_skzb_widget_20");
			self.left_result:setAltas("common_altas_4", "xui_jys_label_1");
			self.right_result:setAltas("common_altas_4", "xui_jys_label_2");
		end

		local role = data.def_role;
		self.leftAvatar:setRoleId(role.id, role.server_flag);
		self.leftAvatar:setRoleDressUp(role.dress_info);

		self.left_role_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);
		self.left_rank.text = LanUtil.formateStr(770012, tostring(data.def_rank));

		role = data.att_role;
		self.rightAvatar:setRoleId(role.id, role.server_flag);
		self.rightAvatar:setRoleDressUp(role.dress_info);

		self.right_role_name.text = LanUtil.formateStr(10066, role.server_prev, role.name);
		self.right_rank.text = LanUtil.formateStr(770012, tostring(data.att_rank));
	end
	
	local config = DataCenter.timeSpaceRaceUtil:getTimeSpaceConfig(data.type);
	self.left_name.text = config.name;
	self.right_name.text = config.name;
	self.matchTime.text = os.date("%Y-%m-%d %H:%M", tonumber(data.fight_tick));
end

function Lua_TimeSpaceFightRecordItem:onCheckDetails()
	Lua_WindowUtil.openWin("Lua_TimeSpaceFightDetailsWindow", Lua_WinParam.ACTION_OPEN, self.data);
end