Lua_TimeSpaceRaceRewardWindow = class("Lua_TimeSpaceRaceRewardWindow", Lua_Window)
function Lua_TimeSpaceRaceRewardWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_TimeSpaceRaceRewardWindow";
	self.skinName = "TimeSpaceRaceRewardWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_TimeSpaceRaceRewardWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("TIME_SPACE_ACTIVE_REWARD", self, self.updateActiveReward);

	self.itemList = Lua_DragContainer.new(self.content, 644, 550, Lua_AxisDefine.Vertical);
	self.itemList.tweenId = 2023;
	self.itemList.delayTween = true;
	self.itemList:setCellSpacing(0, 5);

	self.btnInfo = Array();
	self.btnInfo:add(770015);
	self.btnInfo:add(770016);
	self.btnInfo:add({ textStr = LanUtil.getValue(770017), redPointId = Lua_RedPointList.TimeSpaceRace_Reward });

	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.buttonList:setLocation(0, -445.5, 0);
	self.buttonList:setButtonCell(Lua_CommonButtonItem2);
	self.buttonList:setButtonItem(160, 67);
	self.buttonList:setRedPoint(78, 12);
	self.buttonList:setClickCallBack(self, self.onButtonClick);
	self.buttonList:setData(self.btnInfo);
	self.buttonList:setSelected(1);
end

function Lua_TimeSpaceRaceRewardWindow:dispose()
	if self.spaceList then
		self.spaceList:dispose();
		self.spaceList = nil;
	end
	if self.buttonList then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	if self.btnInfo then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceRewardWindow:onButtonClick(index, data)
	self.index = index;
	if index == 3 then
		self.showObject_1:SetActive(false);
		self.showObject_2:SetActive(true);
		self.bg:setLocation(0, -20, 0);
		self.bg:SetDimensions(644, 669);
		self:showSpaceList(false);
		Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sActiveReward();
	else
		self.showObject_1:SetActive(true);
		self.showObject_2:SetActive(false);
		self.bg:setLocation(0, -25, 0);
		self.bg:SetDimensions(644, 590);

		self.itemList:setContentRect(644, 570, false);
		self.itemList:setLocation(0, -23, 0);
		self:showSpaceList(true);
	end
end

function Lua_TimeSpaceRaceRewardWindow:showSpaceList(bValue)
	if bValue then
		if self.spaceList == nil then
			local list = DataCenter.timeSpaceRaceUtil.timeSpaceList;
			self.spaceList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
			self.spaceList:setLocation(0, -360, 0);
			self.spaceList:setButtonCell(Lua_TimeSpaceRaceTypeCell);
			self.spaceList:setButtonItem(210, 80);
			self.spaceList:setClickCallBack(self, self.onTimeSpaceSelected);
			self.spaceList:setData(list);
		end
		self.spaceList:setEnable(true);
		self.spaceList.selectedIdx = nil;
		self.spaceList:setSelected(1);
	else
		if self.spaceList then
			self.spaceList:setEnable(false);
		end
	end
end

function Lua_TimeSpaceRaceRewardWindow:onTimeSpaceSelected(index, data)
	self.itemList:clearList();
	self.itemList.showTween = true;
	self.itemList.customParam = index;
	local arr;
	if self.index == 1 then
		arr = DataCenter.timeSpaceRaceUtil:getDailyRewardList();
	else
		arr = DataCenter.timeSpaceRaceUtil:getRankRewardList();
	end
	for i = 1, arr:getSize() do
		self.itemList:addSubContainer(Lua_TimeSpaceRankRewardItem, arr[i]);
	end
	self.itemList:updateChildPos();
	self.itemList:moveToIndex(1, true);
end

function Lua_TimeSpaceRaceRewardWindow:updateActiveReward()
	self.itemList:setContentRect(644, 645, false);
	self.itemList:setLocation(0, -20, 0);
	self.itemList:clearList();
	self.itemList.showTween = true;
	self.itemList.customParam = index;
	local arr = DataCenter.timeSpaceRaceUtil:getActiveRewardList();
	for i = 1, arr:getSize() do
		self.itemList:addSubContainer(Lua_TimeSpaceActiveRewardItem, arr[i]);
	end
	self.itemList:updateChildPos();
	self.itemList:moveToIndex(1, true);

	self.timesText.text = LanUtil.formateStr(770019, tostring(DataCenter.timeSpaceRaceData.fightTimes));
end










Lua_TimeSpaceRaceTypeCell = class("Lua_TimeSpaceRaceTypeCell", Lua_ButtonCell)
function Lua_TimeSpaceRaceTypeCell:ctor(p)
	self:superCall("ctor", p, "TimeSpaceRaceTypeItem_skin");
end

function Lua_TimeSpaceRaceTypeCell:buildShowItem()
	self:superCall("buildShowItem");
	self.bg:setScale(0.92, 0.92, 1);
	self.selectBg:setScale(0.92, 0.92, 1);
	self.condText:setEnable(false);
end

function Lua_TimeSpaceRaceTypeCell:dispose()
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceTypeCell:setData(data)
	self:superCall("setData", data);
	self.bg:setAltas("time_space_atlas", data.bg_sprite);
end

function Lua_TimeSpaceRaceTypeCell:setCanClick(bCan)
	if bCan == true then
		self.bg.mouseEnable = true;
		self.bg:addClickFuntion(self, self.onPressClick);
	else
		self.bg.mouseEnable = false;
		self.bg:removeClickFuntion(self, self.onPressClick);
	end
end

function Lua_TimeSpaceRaceTypeCell:setSelected(index)
	self:superCall("setSelected", index);
	self.selectBg:setEnable(self.index == index);
end










Lua_TimeSpaceRankRewardItem = class("Lua_TimeSpaceRankRewardItem", Lua_DragContainerItem)
function Lua_TimeSpaceRankRewardItem:ctor(p)
	self:superCall("ctor", p, "TimeSpaceRankRewardItem_skin");
end

function Lua_TimeSpaceRankRewardItem:buildShowItem()
	self:superCall("buildShowItem");
	self.spaceType = 1;

	self.itemList = Lua_ItemIconList.new(self.content);
	self.itemList:setLocation(87, 0, 0);
	self.itemList.scaleVal = 0.75;
end

function Lua_TimeSpaceRankRewardItem:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_TimeSpaceRankRewardItem:getWidth()
	return 644;
end

function Lua_TimeSpaceRankRewardItem:getHeight()
	return 120;
end

function Lua_TimeSpaceRankRewardItem:setCustomParam(customParam)
	self.spaceType = customParam;
end

function Lua_TimeSpaceRankRewardItem:setData(data)
	if data.rank_range[1] <= 3 then
		self.rankIcon:setAltas("common_altas_4", "xui_jys_label_1"..(data.rank_range[1] - 1));
		self.rankText:setEnable(false);
	else
		self.rankIcon:setAltas("common_altas_4", "xui_jys_label_13");
		self.rankText:setEnable(true);
		self.rankText.text = data.rank_label;
	end
	self.itemList:setArrayData(data.item_list[self.spaceType]);
end

function Lua_TimeSpaceRankRewardItem:onPressClick()
	self.itemList:onBoundClick();
end










Lua_TimeSpaceActiveRewardItem = class("Lua_TimeSpaceActiveRewardItem", Lua_DragContainerItem)
function Lua_TimeSpaceActiveRewardItem:ctor(p)
	self:superCall("ctor", p, "TimeSpaceActiveRewardItem_skin");
end

function Lua_TimeSpaceActiveRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_ItemIconList.new(self.content);
	self.itemList:setLocation(-250, -22, 0);
	self.itemList.pivot = 1;
	self.itemList.scaleVal = 0.7;

	self.btnReceive:addClickFuntion(self, self.onReceive);
end

function Lua_TimeSpaceActiveRewardItem:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_TimeSpaceActiveRewardItem:getWidth()
	return 644;
end

function Lua_TimeSpaceActiveRewardItem:getHeight()
	return 165;
end

function Lua_TimeSpaceActiveRewardItem:setData(data)
	self.data = data;
	local config = getConfig("time_space_active_reward", data);
	local state = DataCenter.timeSpaceRaceData:getActiveRewardState(data);

	self.titleText.text = LanUtil.formateStr(770018, tostring(config.cond_num));
	self.itemList:setArrayData(config.reward);
	if state == 1 then
		self.btnReceive:setEnable(true);
		self.stateIcon:setEnable(false);
		self:showRedPoint(true);
	else
		self.btnReceive:setEnable(false);
		self.stateIcon:setEnable(true);
		if state == 2 then
			self.stateIcon:setAltas("common_altas_1", "xui_common_label_12");
		else
			self.stateIcon:setAltas("common_altas_4", "xui_common_label_21");
		end
		self:showRedPoint(false);
	end
end

function Lua_TimeSpaceActiveRewardItem:showRedPoint(bValue)
	if bValue then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(262, -5, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_TimeSpaceActiveRewardItem:onReceive(go)
	Lua_ProxyManager.getProxy("Lua_TimeSpaceRaceProxy"):sReceiveActiveReward(self.data);
end

function Lua_TimeSpaceActiveRewardItem:onPressClick()
	self.itemList:onBoundClick();
end